from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.StepData import *
from OCC.Core.StepRepr import *
from OCC.Core.TCollection import *
from OCC.Core.StepBasic import *
from OCC.Core.TColStd import *

#the following typedef cannot be wrapped as is
StepGeom_Array2OfCartesianPoint = NewType('StepGeom_Array2OfCartesianPoint', Any)
#the following typedef cannot be wrapped as is
StepGeom_Array2OfSurfacePatch = NewType('StepGeom_Array2OfSurfacePatch', Any)

class StepGeom_Array1OfBoundaryCurve:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepGeom_Array1OfCartesianPoint:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepGeom_Array1OfCompositeCurveSegment:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepGeom_Array1OfCurve:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> False: ...
    def __setitem__(self, index: int, value: False) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[False]: ...
    def next(self) -> False: ...
    __next__ = next
    def Init(self, theValue: False) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> False: ...
    def Last(self) -> False: ...
    def Value(self, theIndex: int) -> False: ...
    def SetValue(self, theIndex: int, theValue: False) -> None: ...

class StepGeom_Array1OfPcurveOrSurface:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepGeom_PcurveOrSurface: ...
    def __setitem__(self, index: int, value: StepGeom_PcurveOrSurface) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepGeom_PcurveOrSurface]: ...
    def next(self) -> StepGeom_PcurveOrSurface: ...
    __next__ = next
    def Init(self, theValue: StepGeom_PcurveOrSurface) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepGeom_PcurveOrSurface: ...
    def Last(self) -> StepGeom_PcurveOrSurface: ...
    def Value(self, theIndex: int) -> StepGeom_PcurveOrSurface: ...
    def SetValue(self, theIndex: int, theValue: StepGeom_PcurveOrSurface) -> None: ...

class StepGeom_Array1OfSurfaceBoundary:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepGeom_SurfaceBoundary: ...
    def __setitem__(self, index: int, value: StepGeom_SurfaceBoundary) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepGeom_SurfaceBoundary]: ...
    def next(self) -> StepGeom_SurfaceBoundary: ...
    __next__ = next
    def Init(self, theValue: StepGeom_SurfaceBoundary) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepGeom_SurfaceBoundary: ...
    def Last(self) -> StepGeom_SurfaceBoundary: ...
    def Value(self, theIndex: int) -> StepGeom_SurfaceBoundary: ...
    def SetValue(self, theIndex: int, theValue: StepGeom_SurfaceBoundary) -> None: ...

class StepGeom_Array1OfTrimmingSelect:
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def __getitem__(self, index: int) -> StepGeom_TrimmingSelect: ...
    def __setitem__(self, index: int, value: StepGeom_TrimmingSelect) -> None: ...
    def __len__(self) -> int: ...
    def __iter__(self) -> Iterator[StepGeom_TrimmingSelect]: ...
    def next(self) -> StepGeom_TrimmingSelect: ...
    __next__ = next
    def Init(self, theValue: StepGeom_TrimmingSelect) -> None: ...
    def Size(self) -> int: ...
    def Length(self) -> int: ...
    def IsEmpty(self) -> bool: ...
    def Lower(self) -> int: ...
    def Upper(self) -> int: ...
    def IsDetectable(self) -> bool: ...
    def IsAllocated(self) -> bool: ...
    def First(self) -> StepGeom_TrimmingSelect: ...
    def Last(self) -> StepGeom_TrimmingSelect: ...
    def Value(self, theIndex: int) -> StepGeom_TrimmingSelect: ...
    def SetValue(self, theIndex: int, theValue: StepGeom_TrimmingSelect) -> None: ...

class StepGeom_KnotType(IntEnum):
	StepGeom_ktUniformKnots: int = ...
	StepGeom_ktUnspecified: int = ...
	StepGeom_ktQuasiUniformKnots: int = ...
	StepGeom_ktPiecewiseBezierKnots: int = ...
StepGeom_ktUniformKnots = StepGeom_KnotType.StepGeom_ktUniformKnots
StepGeom_ktUnspecified = StepGeom_KnotType.StepGeom_ktUnspecified
StepGeom_ktQuasiUniformKnots = StepGeom_KnotType.StepGeom_ktQuasiUniformKnots
StepGeom_ktPiecewiseBezierKnots = StepGeom_KnotType.StepGeom_ktPiecewiseBezierKnots

class StepGeom_BSplineSurfaceForm(IntEnum):
	StepGeom_bssfPlaneSurf: int = ...
	StepGeom_bssfCylindricalSurf: int = ...
	StepGeom_bssfConicalSurf: int = ...
	StepGeom_bssfSphericalSurf: int = ...
	StepGeom_bssfToroidalSurf: int = ...
	StepGeom_bssfSurfOfRevolution: int = ...
	StepGeom_bssfRuledSurf: int = ...
	StepGeom_bssfGeneralisedCone: int = ...
	StepGeom_bssfQuadricSurf: int = ...
	StepGeom_bssfSurfOfLinearExtrusion: int = ...
	StepGeom_bssfUnspecified: int = ...
StepGeom_bssfPlaneSurf = StepGeom_BSplineSurfaceForm.StepGeom_bssfPlaneSurf
StepGeom_bssfCylindricalSurf = StepGeom_BSplineSurfaceForm.StepGeom_bssfCylindricalSurf
StepGeom_bssfConicalSurf = StepGeom_BSplineSurfaceForm.StepGeom_bssfConicalSurf
StepGeom_bssfSphericalSurf = StepGeom_BSplineSurfaceForm.StepGeom_bssfSphericalSurf
StepGeom_bssfToroidalSurf = StepGeom_BSplineSurfaceForm.StepGeom_bssfToroidalSurf
StepGeom_bssfSurfOfRevolution = StepGeom_BSplineSurfaceForm.StepGeom_bssfSurfOfRevolution
StepGeom_bssfRuledSurf = StepGeom_BSplineSurfaceForm.StepGeom_bssfRuledSurf
StepGeom_bssfGeneralisedCone = StepGeom_BSplineSurfaceForm.StepGeom_bssfGeneralisedCone
StepGeom_bssfQuadricSurf = StepGeom_BSplineSurfaceForm.StepGeom_bssfQuadricSurf
StepGeom_bssfSurfOfLinearExtrusion = StepGeom_BSplineSurfaceForm.StepGeom_bssfSurfOfLinearExtrusion
StepGeom_bssfUnspecified = StepGeom_BSplineSurfaceForm.StepGeom_bssfUnspecified

class StepGeom_BSplineCurveForm(IntEnum):
	StepGeom_bscfPolylineForm: int = ...
	StepGeom_bscfCircularArc: int = ...
	StepGeom_bscfEllipticArc: int = ...
	StepGeom_bscfParabolicArc: int = ...
	StepGeom_bscfHyperbolicArc: int = ...
	StepGeom_bscfUnspecified: int = ...
StepGeom_bscfPolylineForm = StepGeom_BSplineCurveForm.StepGeom_bscfPolylineForm
StepGeom_bscfCircularArc = StepGeom_BSplineCurveForm.StepGeom_bscfCircularArc
StepGeom_bscfEllipticArc = StepGeom_BSplineCurveForm.StepGeom_bscfEllipticArc
StepGeom_bscfParabolicArc = StepGeom_BSplineCurveForm.StepGeom_bscfParabolicArc
StepGeom_bscfHyperbolicArc = StepGeom_BSplineCurveForm.StepGeom_bscfHyperbolicArc
StepGeom_bscfUnspecified = StepGeom_BSplineCurveForm.StepGeom_bscfUnspecified

class StepGeom_TrimmingPreference(IntEnum):
	StepGeom_tpCartesian: int = ...
	StepGeom_tpParameter: int = ...
	StepGeom_tpUnspecified: int = ...
StepGeom_tpCartesian = StepGeom_TrimmingPreference.StepGeom_tpCartesian
StepGeom_tpParameter = StepGeom_TrimmingPreference.StepGeom_tpParameter
StepGeom_tpUnspecified = StepGeom_TrimmingPreference.StepGeom_tpUnspecified

class StepGeom_PreferredSurfaceCurveRepresentation(IntEnum):
	StepGeom_pscrCurve3d: int = ...
	StepGeom_pscrPcurveS1: int = ...
	StepGeom_pscrPcurveS2: int = ...
StepGeom_pscrCurve3d = StepGeom_PreferredSurfaceCurveRepresentation.StepGeom_pscrCurve3d
StepGeom_pscrPcurveS1 = StepGeom_PreferredSurfaceCurveRepresentation.StepGeom_pscrPcurveS1
StepGeom_pscrPcurveS2 = StepGeom_PreferredSurfaceCurveRepresentation.StepGeom_pscrPcurveS2

class StepGeom_TransitionCode(IntEnum):
	StepGeom_tcDiscontinuous: int = ...
	StepGeom_tcContinuous: int = ...
	StepGeom_tcContSameGradient: int = ...
	StepGeom_tcContSameGradientSameCurvature: int = ...
StepGeom_tcDiscontinuous = StepGeom_TransitionCode.StepGeom_tcDiscontinuous
StepGeom_tcContinuous = StepGeom_TransitionCode.StepGeom_tcContinuous
StepGeom_tcContSameGradient = StepGeom_TransitionCode.StepGeom_tcContSameGradient
StepGeom_tcContSameGradientSameCurvature = StepGeom_TransitionCode.StepGeom_tcContSameGradientSameCurvature

class StepGeom_Axis2Placement(StepData_SelectType):
	def __init__(self) -> None: ...
	def Axis2Placement2d(self) -> StepGeom_Axis2Placement2d: ...
	def Axis2Placement3d(self) -> StepGeom_Axis2Placement3d: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...

class StepGeom_CompositeCurveSegment(Standard_Transient):
	def __init__(self) -> None: ...
	def Init(self, aTransition: StepGeom_TransitionCode, aSameSense: bool, aParentCurve: StepGeom_Curve) -> None: ...
	def ParentCurve(self) -> StepGeom_Curve: ...
	def SameSense(self) -> bool: ...
	def SetParentCurve(self, aParentCurve: StepGeom_Curve) -> None: ...
	def SetSameSense(self, aSameSense: bool) -> None: ...
	def SetTransition(self, aTransition: StepGeom_TransitionCode) -> None: ...
	def Transition(self) -> StepGeom_TransitionCode: ...

class StepGeom_CurveOnSurface(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def CompositeCurveOnSurface(self) -> StepGeom_CompositeCurveOnSurface: ...
	def Pcurve(self) -> StepGeom_Pcurve: ...
	def SurfaceCurve(self) -> StepGeom_SurfaceCurve: ...

class StepGeom_GeomRepContextAndGlobUnitAssCtxAndGlobUncertaintyAssCtx(StepRepr_RepresentationContext):
	def __init__(self) -> None: ...
	def CoordinateSpaceDimension(self) -> int: ...
	def GeometricRepresentationContext(self) -> StepGeom_GeometricRepresentationContext: ...
	def GlobalUncertaintyAssignedContext(self) -> StepRepr_GlobalUncertaintyAssignedContext: ...
	def GlobalUnitAssignedContext(self) -> StepRepr_GlobalUnitAssignedContext: ...
	@overload
	def Init(self, aContextIdentifier: TCollection_HAsciiString, aContextType: TCollection_HAsciiString, aGeometricRepresentationCtx: StepGeom_GeometricRepresentationContext, aGlobalUnitAssignedCtx: StepRepr_GlobalUnitAssignedContext, aGlobalUncertaintyAssignedCtx: StepRepr_GlobalUncertaintyAssignedContext) -> None: ...
	@overload
	def Init(self, aContextIdentifier: TCollection_HAsciiString, aContextType: TCollection_HAsciiString, aCoordinateSpaceDimension: int, aUnits: StepBasic_HArray1OfNamedUnit, anUncertainty: StepBasic_HArray1OfUncertaintyMeasureWithUnit) -> None: ...
	def NbUncertainty(self) -> int: ...
	def NbUnits(self) -> int: ...
	def SetCoordinateSpaceDimension(self, aCoordinateSpaceDimension: int) -> None: ...
	def SetGeometricRepresentationContext(self, aGeometricRepresentationContext: StepGeom_GeometricRepresentationContext) -> None: ...
	def SetGlobalUncertaintyAssignedContext(self, aGlobalUncertaintyAssignedCtx: StepRepr_GlobalUncertaintyAssignedContext) -> None: ...
	def SetGlobalUnitAssignedContext(self, aGlobalUnitAssignedContext: StepRepr_GlobalUnitAssignedContext) -> None: ...
	def SetUncertainty(self, aUncertainty: StepBasic_HArray1OfUncertaintyMeasureWithUnit) -> None: ...
	def SetUnits(self, aUnits: StepBasic_HArray1OfNamedUnit) -> None: ...
	def Uncertainty(self) -> StepBasic_HArray1OfUncertaintyMeasureWithUnit: ...
	def UncertaintyValue(self, num: int) -> StepBasic_UncertaintyMeasureWithUnit: ...
	def Units(self) -> StepBasic_HArray1OfNamedUnit: ...
	def UnitsValue(self, num: int) -> StepBasic_NamedUnit: ...

class StepGeom_GeometricRepresentationContext(StepRepr_RepresentationContext):
	def __init__(self) -> None: ...
	def CoordinateSpaceDimension(self) -> int: ...
	def Init(self, aContextIdentifier: TCollection_HAsciiString, aContextType: TCollection_HAsciiString, aCoordinateSpaceDimension: int) -> None: ...
	def SetCoordinateSpaceDimension(self, aCoordinateSpaceDimension: int) -> None: ...

class StepGeom_GeometricRepresentationContextAndGlobalUnitAssignedContext(StepRepr_RepresentationContext):
	def __init__(self) -> None: ...
	def CoordinateSpaceDimension(self) -> int: ...
	def GeometricRepresentationContext(self) -> StepGeom_GeometricRepresentationContext: ...
	def GlobalUnitAssignedContext(self) -> StepRepr_GlobalUnitAssignedContext: ...
	@overload
	def Init(self, aContextIdentifier: TCollection_HAsciiString, aContextType: TCollection_HAsciiString, aGeometricRepresentationContext: StepGeom_GeometricRepresentationContext, aGlobalUnitAssignedContext: StepRepr_GlobalUnitAssignedContext) -> None: ...
	@overload
	def Init(self, aContextIdentifier: TCollection_HAsciiString, aContextType: TCollection_HAsciiString, aCoordinateSpaceDimension: int, aUnits: StepBasic_HArray1OfNamedUnit) -> None: ...
	def NbUnits(self) -> int: ...
	def SetCoordinateSpaceDimension(self, aCoordinateSpaceDimension: int) -> None: ...
	def SetGeometricRepresentationContext(self, aGeometricRepresentationContext: StepGeom_GeometricRepresentationContext) -> None: ...
	def SetGlobalUnitAssignedContext(self, aGlobalUnitAssignedContext: StepRepr_GlobalUnitAssignedContext) -> None: ...
	def SetUnits(self, aUnits: StepBasic_HArray1OfNamedUnit) -> None: ...
	def Units(self) -> StepBasic_HArray1OfNamedUnit: ...
	def UnitsValue(self, num: int) -> StepBasic_NamedUnit: ...

class StepGeom_GeometricRepresentationContextAndParametricRepresentationContext(StepRepr_RepresentationContext):
	def __init__(self) -> None: ...
	def CoordinateSpaceDimension(self) -> int: ...
	def GeometricRepresentationContext(self) -> StepGeom_GeometricRepresentationContext: ...
	@overload
	def Init(self, aContextIdentifier: TCollection_HAsciiString, aContextType: TCollection_HAsciiString, aGeometricRepresentationContext: StepGeom_GeometricRepresentationContext, aParametricRepresentationContext: StepRepr_ParametricRepresentationContext) -> None: ...
	@overload
	def Init(self, aContextIdentifier: TCollection_HAsciiString, aContextType: TCollection_HAsciiString, aCoordinateSpaceDimension: int) -> None: ...
	def ParametricRepresentationContext(self) -> StepRepr_ParametricRepresentationContext: ...
	def SetCoordinateSpaceDimension(self, aCoordinateSpaceDimension: int) -> None: ...
	def SetGeometricRepresentationContext(self, aGeometricRepresentationContext: StepGeom_GeometricRepresentationContext) -> None: ...
	def SetParametricRepresentationContext(self, aParametricRepresentationContext: StepRepr_ParametricRepresentationContext) -> None: ...

class StepGeom_GeometricRepresentationItem(StepRepr_RepresentationItem):
	def __init__(self) -> None: ...

class StepGeom_PcurveOrSurface(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def Pcurve(self) -> StepGeom_Pcurve: ...
	def Surface(self) -> StepGeom_Surface: ...

class StepGeom_SurfaceBoundary(StepData_SelectType):
	def __init__(self) -> None: ...
	def BoundaryCurve(self) -> StepGeom_BoundaryCurve: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def DegeneratePcurve(self) -> StepGeom_DegeneratePcurve: ...

class StepGeom_SurfacePatch(Standard_Transient):
	def __init__(self) -> None: ...
	def Init(self, aParentSurface: StepGeom_BoundedSurface, aUTransition: StepGeom_TransitionCode, aVTransition: StepGeom_TransitionCode, aUSense: bool, aVSense: bool) -> None: ...
	def ParentSurface(self) -> StepGeom_BoundedSurface: ...
	def SetParentSurface(self, aParentSurface: StepGeom_BoundedSurface) -> None: ...
	def SetUSense(self, aUSense: bool) -> None: ...
	def SetUTransition(self, aUTransition: StepGeom_TransitionCode) -> None: ...
	def SetVSense(self, aVSense: bool) -> None: ...
	def SetVTransition(self, aVTransition: StepGeom_TransitionCode) -> None: ...
	def USense(self) -> bool: ...
	def UTransition(self) -> StepGeom_TransitionCode: ...
	def VSense(self) -> bool: ...
	def VTransition(self) -> StepGeom_TransitionCode: ...

class StepGeom_TrimmingMember(StepData_SelectReal):
	def __init__(self) -> None: ...
	def HasName(self) -> bool: ...
	def Name(self) -> str: ...
	def SetName(self, name: str) -> bool: ...

class StepGeom_TrimmingSelect(StepData_SelectType):
	def __init__(self) -> None: ...
	def CartesianPoint(self) -> StepGeom_CartesianPoint: ...
	def CaseMem(self, ent: StepData_SelectMember) -> int: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def NewMember(self) -> StepData_SelectMember: ...
	def ParameterValue(self) -> float: ...
	def SetParameterValue(self, aParameterValue: float) -> None: ...

class StepGeom_VectorOrDirection(StepData_SelectType):
	def __init__(self) -> None: ...
	def CaseNum(self, ent: Standard_Transient) -> int: ...
	def Direction(self) -> StepGeom_Direction: ...
	def Vector(self) -> StepGeom_Vector: ...

class StepGeom_CartesianTransformationOperator(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...
	def Axis1(self) -> StepGeom_Direction: ...
	def Axis2(self) -> StepGeom_Direction: ...
	def HasAxis1(self) -> bool: ...
	def HasAxis2(self) -> bool: ...
	def HasScale(self) -> bool: ...
	def Init(self, aName: TCollection_HAsciiString, hasAaxis1: bool, aAxis1: StepGeom_Direction, hasAaxis2: bool, aAxis2: StepGeom_Direction, aLocalOrigin: StepGeom_CartesianPoint, hasAscale: bool, aScale: float) -> None: ...
	def LocalOrigin(self) -> StepGeom_CartesianPoint: ...
	def Scale(self) -> float: ...
	def SetAxis1(self, aAxis1: StepGeom_Direction) -> None: ...
	def SetAxis2(self, aAxis2: StepGeom_Direction) -> None: ...
	def SetLocalOrigin(self, aLocalOrigin: StepGeom_CartesianPoint) -> None: ...
	def SetScale(self, aScale: float) -> None: ...
	def UnSetAxis1(self) -> None: ...
	def UnSetAxis2(self) -> None: ...
	def UnSetScale(self) -> None: ...

class StepGeom_Curve(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...

class StepGeom_Direction(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...
	def DirectionRatios(self) -> TColStd_HArray1OfReal: ...
	def DirectionRatiosValue(self, num: int) -> float: ...
	def Init(self, aName: TCollection_HAsciiString, aDirectionRatios: TColStd_HArray1OfReal) -> None: ...
	def NbDirectionRatios(self) -> int: ...
	def SetDirectionRatios(self, aDirectionRatios: TColStd_HArray1OfReal) -> None: ...

class StepGeom_Placement(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aLocation: StepGeom_CartesianPoint) -> None: ...
	def Location(self) -> StepGeom_CartesianPoint: ...
	def SetLocation(self, aLocation: StepGeom_CartesianPoint) -> None: ...

class StepGeom_Point(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...

class StepGeom_ReparametrisedCompositeCurveSegment(StepGeom_CompositeCurveSegment):
	def __init__(self) -> None: ...
	def Init(self, aTransition: StepGeom_TransitionCode, aSameSense: bool, aParentCurve: StepGeom_Curve, aParamLength: float) -> None: ...
	def ParamLength(self) -> float: ...
	def SetParamLength(self, aParamLength: float) -> None: ...

class StepGeom_Surface(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...

class StepGeom_Vector(StepGeom_GeometricRepresentationItem):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aOrientation: StepGeom_Direction, aMagnitude: float) -> None: ...
	def Magnitude(self) -> float: ...
	def Orientation(self) -> StepGeom_Direction: ...
	def SetMagnitude(self, aMagnitude: float) -> None: ...
	def SetOrientation(self, aOrientation: StepGeom_Direction) -> None: ...

class StepGeom_Axis1Placement(StepGeom_Placement):
	def __init__(self) -> None: ...
	def Axis(self) -> StepGeom_Direction: ...
	def HasAxis(self) -> bool: ...
	def Init(self, aName: TCollection_HAsciiString, aLocation: StepGeom_CartesianPoint, hasAaxis: bool, aAxis: StepGeom_Direction) -> None: ...
	def SetAxis(self, aAxis: StepGeom_Direction) -> None: ...
	def UnSetAxis(self) -> None: ...

class StepGeom_Axis2Placement2d(StepGeom_Placement):
	def __init__(self) -> None: ...
	def HasRefDirection(self) -> bool: ...
	def Init(self, aName: TCollection_HAsciiString, aLocation: StepGeom_CartesianPoint, hasArefDirection: bool, aRefDirection: StepGeom_Direction) -> None: ...
	def RefDirection(self) -> StepGeom_Direction: ...
	def SetRefDirection(self, aRefDirection: StepGeom_Direction) -> None: ...
	def UnSetRefDirection(self) -> None: ...

class StepGeom_Axis2Placement3d(StepGeom_Placement):
	def __init__(self) -> None: ...
	def Axis(self) -> StepGeom_Direction: ...
	def HasAxis(self) -> bool: ...
	def HasRefDirection(self) -> bool: ...
	def Init(self, aName: TCollection_HAsciiString, aLocation: StepGeom_CartesianPoint, hasAaxis: bool, aAxis: StepGeom_Direction, hasArefDirection: bool, aRefDirection: StepGeom_Direction) -> None: ...
	def RefDirection(self) -> StepGeom_Direction: ...
	def SetAxis(self, aAxis: StepGeom_Direction) -> None: ...
	def SetRefDirection(self, aRefDirection: StepGeom_Direction) -> None: ...
	def UnSetAxis(self) -> None: ...
	def UnSetRefDirection(self) -> None: ...

class StepGeom_BoundedCurve(StepGeom_Curve):
	def __init__(self) -> None: ...

class StepGeom_BoundedSurface(StepGeom_Surface):
	def __init__(self) -> None: ...

class StepGeom_CartesianPoint(StepGeom_Point):
	def __init__(self) -> None: ...
	def Coordinates(self) -> TColStd_HArray1OfReal: ...
	def CoordinatesValue(self, num: int) -> float: ...
	def Init(self, aName: TCollection_HAsciiString, aCoordinates: TColStd_HArray1OfReal) -> None: ...
	def Init2D(self, aName: TCollection_HAsciiString, X: float, Y: float) -> None: ...
	def Init3D(self, aName: TCollection_HAsciiString, X: float, Y: float, Z: float) -> None: ...
	def NbCoordinates(self) -> int: ...
	def SetCoordinates(self, aCoordinates: TColStd_HArray1OfReal) -> None: ...

class StepGeom_CartesianTransformationOperator2d(StepGeom_CartesianTransformationOperator):
	def __init__(self) -> None: ...

class StepGeom_CartesianTransformationOperator3d(StepGeom_CartesianTransformationOperator):
	def __init__(self) -> None: ...
	def Axis3(self) -> StepGeom_Direction: ...
	def HasAxis3(self) -> bool: ...
	def Init(self, aName: TCollection_HAsciiString, hasAaxis1: bool, aAxis1: StepGeom_Direction, hasAaxis2: bool, aAxis2: StepGeom_Direction, aLocalOrigin: StepGeom_CartesianPoint, hasAscale: bool, aScale: float, hasAaxis3: bool, aAxis3: StepGeom_Direction) -> None: ...
	def SetAxis3(self, aAxis3: StepGeom_Direction) -> None: ...
	def UnSetAxis3(self) -> None: ...

class StepGeom_Conic(StepGeom_Curve):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aPosition: StepGeom_Axis2Placement) -> None: ...
	def Position(self) -> StepGeom_Axis2Placement: ...
	def SetPosition(self, aPosition: StepGeom_Axis2Placement) -> None: ...

class StepGeom_CurveReplica(StepGeom_Curve):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aParentCurve: StepGeom_Curve, aTransformation: StepGeom_CartesianTransformationOperator) -> None: ...
	def ParentCurve(self) -> StepGeom_Curve: ...
	def SetParentCurve(self, aParentCurve: StepGeom_Curve) -> None: ...
	def SetTransformation(self, aTransformation: StepGeom_CartesianTransformationOperator) -> None: ...
	def Transformation(self) -> StepGeom_CartesianTransformationOperator: ...

class StepGeom_DegeneratePcurve(StepGeom_Point):
	def __init__(self) -> None: ...
	def BasisSurface(self) -> StepGeom_Surface: ...
	def Init(self, aName: TCollection_HAsciiString, aBasisSurface: StepGeom_Surface, aReferenceToCurve: StepRepr_DefinitionalRepresentation) -> None: ...
	def ReferenceToCurve(self) -> StepRepr_DefinitionalRepresentation: ...
	def SetBasisSurface(self, aBasisSurface: StepGeom_Surface) -> None: ...
	def SetReferenceToCurve(self, aReferenceToCurve: StepRepr_DefinitionalRepresentation) -> None: ...

class StepGeom_ElementarySurface(StepGeom_Surface):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aPosition: StepGeom_Axis2Placement3d) -> None: ...
	def Position(self) -> StepGeom_Axis2Placement3d: ...
	def SetPosition(self, aPosition: StepGeom_Axis2Placement3d) -> None: ...

class StepGeom_Line(StepGeom_Curve):
	def __init__(self) -> None: ...
	def Dir(self) -> StepGeom_Vector: ...
	def Init(self, aName: TCollection_HAsciiString, aPnt: StepGeom_CartesianPoint, aDir: StepGeom_Vector) -> None: ...
	def Pnt(self) -> StepGeom_CartesianPoint: ...
	def SetDir(self, aDir: StepGeom_Vector) -> None: ...
	def SetPnt(self, aPnt: StepGeom_CartesianPoint) -> None: ...

class StepGeom_OffsetCurve3d(StepGeom_Curve):
	def __init__(self) -> None: ...
	def BasisCurve(self) -> StepGeom_Curve: ...
	def Distance(self) -> float: ...
	def Init(self, aName: TCollection_HAsciiString, aBasisCurve: StepGeom_Curve, aDistance: float, aSelfIntersect: StepData_Logical, aRefDirection: StepGeom_Direction) -> None: ...
	def RefDirection(self) -> StepGeom_Direction: ...
	def SelfIntersect(self) -> StepData_Logical: ...
	def SetBasisCurve(self, aBasisCurve: StepGeom_Curve) -> None: ...
	def SetDistance(self, aDistance: float) -> None: ...
	def SetRefDirection(self, aRefDirection: StepGeom_Direction) -> None: ...
	def SetSelfIntersect(self, aSelfIntersect: StepData_Logical) -> None: ...

class StepGeom_OffsetSurface(StepGeom_Surface):
	def __init__(self) -> None: ...
	def BasisSurface(self) -> StepGeom_Surface: ...
	def Distance(self) -> float: ...
	def Init(self, aName: TCollection_HAsciiString, aBasisSurface: StepGeom_Surface, aDistance: float, aSelfIntersect: StepData_Logical) -> None: ...
	def SelfIntersect(self) -> StepData_Logical: ...
	def SetBasisSurface(self, aBasisSurface: StepGeom_Surface) -> None: ...
	def SetDistance(self, aDistance: float) -> None: ...
	def SetSelfIntersect(self, aSelfIntersect: StepData_Logical) -> None: ...

class StepGeom_OrientedSurface(StepGeom_Surface):
	def __init__(self) -> None: ...
	def Init(self, aRepresentationItem_Name: TCollection_HAsciiString, aOrientation: bool) -> None: ...
	def Orientation(self) -> bool: ...
	def SetOrientation(self, Orientation: bool) -> None: ...

class StepGeom_Pcurve(StepGeom_Curve):
	def __init__(self) -> None: ...
	def BasisSurface(self) -> StepGeom_Surface: ...
	def Init(self, aName: TCollection_HAsciiString, aBasisSurface: StepGeom_Surface, aReferenceToCurve: StepRepr_DefinitionalRepresentation) -> None: ...
	def ReferenceToCurve(self) -> StepRepr_DefinitionalRepresentation: ...
	def SetBasisSurface(self, aBasisSurface: StepGeom_Surface) -> None: ...
	def SetReferenceToCurve(self, aReferenceToCurve: StepRepr_DefinitionalRepresentation) -> None: ...

class StepGeom_PointOnCurve(StepGeom_Point):
	def __init__(self) -> None: ...
	def BasisCurve(self) -> StepGeom_Curve: ...
	def Init(self, aName: TCollection_HAsciiString, aBasisCurve: StepGeom_Curve, aPointParameter: float) -> None: ...
	def PointParameter(self) -> float: ...
	def SetBasisCurve(self, aBasisCurve: StepGeom_Curve) -> None: ...
	def SetPointParameter(self, aPointParameter: float) -> None: ...

class StepGeom_PointOnSurface(StepGeom_Point):
	def __init__(self) -> None: ...
	def BasisSurface(self) -> StepGeom_Surface: ...
	def Init(self, aName: TCollection_HAsciiString, aBasisSurface: StepGeom_Surface, aPointParameterU: float, aPointParameterV: float) -> None: ...
	def PointParameterU(self) -> float: ...
	def PointParameterV(self) -> float: ...
	def SetBasisSurface(self, aBasisSurface: StepGeom_Surface) -> None: ...
	def SetPointParameterU(self, aPointParameterU: float) -> None: ...
	def SetPointParameterV(self, aPointParameterV: float) -> None: ...

class StepGeom_PointReplica(StepGeom_Point):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aParentPt: StepGeom_Point, aTransformation: StepGeom_CartesianTransformationOperator) -> None: ...
	def ParentPt(self) -> StepGeom_Point: ...
	def SetParentPt(self, aParentPt: StepGeom_Point) -> None: ...
	def SetTransformation(self, aTransformation: StepGeom_CartesianTransformationOperator) -> None: ...
	def Transformation(self) -> StepGeom_CartesianTransformationOperator: ...

class StepGeom_SurfaceCurve(StepGeom_Curve):
	def __init__(self) -> None: ...
	def AssociatedGeometry(self) -> StepGeom_HArray1OfPcurveOrSurface: ...
	def AssociatedGeometryValue(self, num: int) -> StepGeom_PcurveOrSurface: ...
	def Curve3d(self) -> StepGeom_Curve: ...
	def Init(self, aName: TCollection_HAsciiString, aCurve3d: StepGeom_Curve, aAssociatedGeometry: StepGeom_HArray1OfPcurveOrSurface, aMasterRepresentation: StepGeom_PreferredSurfaceCurveRepresentation) -> None: ...
	def MasterRepresentation(self) -> StepGeom_PreferredSurfaceCurveRepresentation: ...
	def NbAssociatedGeometry(self) -> int: ...
	def SetAssociatedGeometry(self, aAssociatedGeometry: StepGeom_HArray1OfPcurveOrSurface) -> None: ...
	def SetCurve3d(self, aCurve3d: StepGeom_Curve) -> None: ...
	def SetMasterRepresentation(self, aMasterRepresentation: StepGeom_PreferredSurfaceCurveRepresentation) -> None: ...

class StepGeom_SurfaceReplica(StepGeom_Surface):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aParentSurface: StepGeom_Surface, aTransformation: StepGeom_CartesianTransformationOperator3d) -> None: ...
	def ParentSurface(self) -> StepGeom_Surface: ...
	def SetParentSurface(self, aParentSurface: StepGeom_Surface) -> None: ...
	def SetTransformation(self, aTransformation: StepGeom_CartesianTransformationOperator3d) -> None: ...
	def Transformation(self) -> StepGeom_CartesianTransformationOperator3d: ...

class StepGeom_SweptSurface(StepGeom_Surface):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aSweptCurve: StepGeom_Curve) -> None: ...
	def SetSweptCurve(self, aSweptCurve: StepGeom_Curve) -> None: ...
	def SweptCurve(self) -> StepGeom_Curve: ...

class StepGeom_BSplineCurve(StepGeom_BoundedCurve):
	def __init__(self) -> None: ...
	def ClosedCurve(self) -> StepData_Logical: ...
	def ControlPointsList(self) -> StepGeom_HArray1OfCartesianPoint: ...
	def ControlPointsListValue(self, num: int) -> StepGeom_CartesianPoint: ...
	def CurveForm(self) -> StepGeom_BSplineCurveForm: ...
	def Degree(self) -> int: ...
	def Init(self, aName: TCollection_HAsciiString, aDegree: int, aControlPointsList: StepGeom_HArray1OfCartesianPoint, aCurveForm: StepGeom_BSplineCurveForm, aClosedCurve: StepData_Logical, aSelfIntersect: StepData_Logical) -> None: ...
	def NbControlPointsList(self) -> int: ...
	def SelfIntersect(self) -> StepData_Logical: ...
	def SetClosedCurve(self, aClosedCurve: StepData_Logical) -> None: ...
	def SetControlPointsList(self, aControlPointsList: StepGeom_HArray1OfCartesianPoint) -> None: ...
	def SetCurveForm(self, aCurveForm: StepGeom_BSplineCurveForm) -> None: ...
	def SetDegree(self, aDegree: int) -> None: ...
	def SetSelfIntersect(self, aSelfIntersect: StepData_Logical) -> None: ...

class StepGeom_BSplineSurface(StepGeom_BoundedSurface):
	def __init__(self) -> None: ...
	def ControlPointsList(self) -> StepGeom_HArray2OfCartesianPoint: ...
	def ControlPointsListValue(self, num1: int, num2: int) -> StepGeom_CartesianPoint: ...
	def Init(self, aName: TCollection_HAsciiString, aUDegree: int, aVDegree: int, aControlPointsList: StepGeom_HArray2OfCartesianPoint, aSurfaceForm: StepGeom_BSplineSurfaceForm, aUClosed: StepData_Logical, aVClosed: StepData_Logical, aSelfIntersect: StepData_Logical) -> None: ...
	def NbControlPointsListI(self) -> int: ...
	def NbControlPointsListJ(self) -> int: ...
	def SelfIntersect(self) -> StepData_Logical: ...
	def SetControlPointsList(self, aControlPointsList: StepGeom_HArray2OfCartesianPoint) -> None: ...
	def SetSelfIntersect(self, aSelfIntersect: StepData_Logical) -> None: ...
	def SetSurfaceForm(self, aSurfaceForm: StepGeom_BSplineSurfaceForm) -> None: ...
	def SetUClosed(self, aUClosed: StepData_Logical) -> None: ...
	def SetUDegree(self, aUDegree: int) -> None: ...
	def SetVClosed(self, aVClosed: StepData_Logical) -> None: ...
	def SetVDegree(self, aVDegree: int) -> None: ...
	def SurfaceForm(self) -> StepGeom_BSplineSurfaceForm: ...
	def UClosed(self) -> StepData_Logical: ...
	def UDegree(self) -> int: ...
	def VClosed(self) -> StepData_Logical: ...
	def VDegree(self) -> int: ...

class StepGeom_Circle(StepGeom_Conic):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aPosition: StepGeom_Axis2Placement, aRadius: float) -> None: ...
	def Radius(self) -> float: ...
	def SetRadius(self, aRadius: float) -> None: ...

class StepGeom_CompositeCurve(StepGeom_BoundedCurve):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aSegments: StepGeom_HArray1OfCompositeCurveSegment, aSelfIntersect: StepData_Logical) -> None: ...
	def NbSegments(self) -> int: ...
	def Segments(self) -> StepGeom_HArray1OfCompositeCurveSegment: ...
	def SegmentsValue(self, num: int) -> StepGeom_CompositeCurveSegment: ...
	def SelfIntersect(self) -> StepData_Logical: ...
	def SetSegments(self, aSegments: StepGeom_HArray1OfCompositeCurveSegment) -> None: ...
	def SetSelfIntersect(self, aSelfIntersect: StepData_Logical) -> None: ...

class StepGeom_ConicalSurface(StepGeom_ElementarySurface):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aPosition: StepGeom_Axis2Placement3d, aRadius: float, aSemiAngle: float) -> None: ...
	def Radius(self) -> float: ...
	def SemiAngle(self) -> float: ...
	def SetRadius(self, aRadius: float) -> None: ...
	def SetSemiAngle(self, aSemiAngle: float) -> None: ...

class StepGeom_CurveBoundedSurface(StepGeom_BoundedSurface):
	def __init__(self) -> None: ...
	def BasisSurface(self) -> StepGeom_Surface: ...
	def Boundaries(self) -> StepGeom_HArray1OfSurfaceBoundary: ...
	def ImplicitOuter(self) -> bool: ...
	def Init(self, aRepresentationItem_Name: TCollection_HAsciiString, aBasisSurface: StepGeom_Surface, aBoundaries: StepGeom_HArray1OfSurfaceBoundary, aImplicitOuter: bool) -> None: ...
	def SetBasisSurface(self, BasisSurface: StepGeom_Surface) -> None: ...
	def SetBoundaries(self, Boundaries: StepGeom_HArray1OfSurfaceBoundary) -> None: ...
	def SetImplicitOuter(self, ImplicitOuter: bool) -> None: ...

class StepGeom_CylindricalSurface(StepGeom_ElementarySurface):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aPosition: StepGeom_Axis2Placement3d, aRadius: float) -> None: ...
	def Radius(self) -> float: ...
	def SetRadius(self, aRadius: float) -> None: ...

class StepGeom_Ellipse(StepGeom_Conic):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aPosition: StepGeom_Axis2Placement, aSemiAxis1: float, aSemiAxis2: float) -> None: ...
	def SemiAxis1(self) -> float: ...
	def SemiAxis2(self) -> float: ...
	def SetSemiAxis1(self, aSemiAxis1: float) -> None: ...
	def SetSemiAxis2(self, aSemiAxis2: float) -> None: ...

class StepGeom_EvaluatedDegeneratePcurve(StepGeom_DegeneratePcurve):
	def __init__(self) -> None: ...
	def EquivalentPoint(self) -> StepGeom_CartesianPoint: ...
	def Init(self, aName: TCollection_HAsciiString, aBasisSurface: StepGeom_Surface, aReferenceToCurve: StepRepr_DefinitionalRepresentation, aEquivalentPoint: StepGeom_CartesianPoint) -> None: ...
	def SetEquivalentPoint(self, aEquivalentPoint: StepGeom_CartesianPoint) -> None: ...

class StepGeom_Hyperbola(StepGeom_Conic):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aPosition: StepGeom_Axis2Placement, aSemiAxis: float, aSemiImagAxis: float) -> None: ...
	def SemiAxis(self) -> float: ...
	def SemiImagAxis(self) -> float: ...
	def SetSemiAxis(self, aSemiAxis: float) -> None: ...
	def SetSemiImagAxis(self, aSemiImagAxis: float) -> None: ...

class StepGeom_IntersectionCurve(StepGeom_SurfaceCurve):
	def __init__(self) -> None: ...

class StepGeom_Parabola(StepGeom_Conic):
	def __init__(self) -> None: ...
	def FocalDist(self) -> float: ...
	def Init(self, aName: TCollection_HAsciiString, aPosition: StepGeom_Axis2Placement, aFocalDist: float) -> None: ...
	def SetFocalDist(self, aFocalDist: float) -> None: ...

class StepGeom_Plane(StepGeom_ElementarySurface):
	def __init__(self) -> None: ...

class StepGeom_Polyline(StepGeom_BoundedCurve):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aPoints: StepGeom_HArray1OfCartesianPoint) -> None: ...
	def NbPoints(self) -> int: ...
	def Points(self) -> StepGeom_HArray1OfCartesianPoint: ...
	def PointsValue(self, num: int) -> StepGeom_CartesianPoint: ...
	def SetPoints(self, aPoints: StepGeom_HArray1OfCartesianPoint) -> None: ...

class StepGeom_RectangularCompositeSurface(StepGeom_BoundedSurface):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aSegments: StepGeom_HArray2OfSurfacePatch) -> None: ...
	def NbSegmentsI(self) -> int: ...
	def NbSegmentsJ(self) -> int: ...
	def Segments(self) -> StepGeom_HArray2OfSurfacePatch: ...
	def SegmentsValue(self, num1: int, num2: int) -> StepGeom_SurfacePatch: ...
	def SetSegments(self, aSegments: StepGeom_HArray2OfSurfacePatch) -> None: ...

class StepGeom_RectangularTrimmedSurface(StepGeom_BoundedSurface):
	def __init__(self) -> None: ...
	def BasisSurface(self) -> StepGeom_Surface: ...
	def Init(self, aName: TCollection_HAsciiString, aBasisSurface: StepGeom_Surface, aU1: float, aU2: float, aV1: float, aV2: float, aUsense: bool, aVsense: bool) -> None: ...
	def SetBasisSurface(self, aBasisSurface: StepGeom_Surface) -> None: ...
	def SetU1(self, aU1: float) -> None: ...
	def SetU2(self, aU2: float) -> None: ...
	def SetUsense(self, aUsense: bool) -> None: ...
	def SetV1(self, aV1: float) -> None: ...
	def SetV2(self, aV2: float) -> None: ...
	def SetVsense(self, aVsense: bool) -> None: ...
	def U1(self) -> float: ...
	def U2(self) -> float: ...
	def Usense(self) -> bool: ...
	def V1(self) -> float: ...
	def V2(self) -> float: ...
	def Vsense(self) -> bool: ...

class StepGeom_SeamCurve(StepGeom_SurfaceCurve):
	def __init__(self) -> None: ...

class StepGeom_SphericalSurface(StepGeom_ElementarySurface):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aPosition: StepGeom_Axis2Placement3d, aRadius: float) -> None: ...
	def Radius(self) -> float: ...
	def SetRadius(self, aRadius: float) -> None: ...

class StepGeom_SurfaceCurveAndBoundedCurve(StepGeom_SurfaceCurve):
	def __init__(self) -> None: ...
	def BoundedCurve(self) -> StepGeom_BoundedCurve: ...

class StepGeom_SurfaceOfLinearExtrusion(StepGeom_SweptSurface):
	def __init__(self) -> None: ...
	def ExtrusionAxis(self) -> StepGeom_Vector: ...
	def Init(self, aName: TCollection_HAsciiString, aSweptCurve: StepGeom_Curve, aExtrusionAxis: StepGeom_Vector) -> None: ...
	def SetExtrusionAxis(self, aExtrusionAxis: StepGeom_Vector) -> None: ...

class StepGeom_SurfaceOfRevolution(StepGeom_SweptSurface):
	def __init__(self) -> None: ...
	def AxisPosition(self) -> StepGeom_Axis1Placement: ...
	def Init(self, aName: TCollection_HAsciiString, aSweptCurve: StepGeom_Curve, aAxisPosition: StepGeom_Axis1Placement) -> None: ...
	def SetAxisPosition(self, aAxisPosition: StepGeom_Axis1Placement) -> None: ...

class StepGeom_ToroidalSurface(StepGeom_ElementarySurface):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aPosition: StepGeom_Axis2Placement3d, aMajorRadius: float, aMinorRadius: float) -> None: ...
	def MajorRadius(self) -> float: ...
	def MinorRadius(self) -> float: ...
	def SetMajorRadius(self, aMajorRadius: float) -> None: ...
	def SetMinorRadius(self, aMinorRadius: float) -> None: ...

class StepGeom_TrimmedCurve(StepGeom_BoundedCurve):
	def __init__(self) -> None: ...
	def BasisCurve(self) -> StepGeom_Curve: ...
	def Init(self, aName: TCollection_HAsciiString, aBasisCurve: StepGeom_Curve, aTrim1: StepGeom_HArray1OfTrimmingSelect, aTrim2: StepGeom_HArray1OfTrimmingSelect, aSenseAgreement: bool, aMasterRepresentation: StepGeom_TrimmingPreference) -> None: ...
	def MasterRepresentation(self) -> StepGeom_TrimmingPreference: ...
	def NbTrim1(self) -> int: ...
	def NbTrim2(self) -> int: ...
	def SenseAgreement(self) -> bool: ...
	def SetBasisCurve(self, aBasisCurve: StepGeom_Curve) -> None: ...
	def SetMasterRepresentation(self, aMasterRepresentation: StepGeom_TrimmingPreference) -> None: ...
	def SetSenseAgreement(self, aSenseAgreement: bool) -> None: ...
	def SetTrim1(self, aTrim1: StepGeom_HArray1OfTrimmingSelect) -> None: ...
	def SetTrim2(self, aTrim2: StepGeom_HArray1OfTrimmingSelect) -> None: ...
	def Trim1(self) -> StepGeom_HArray1OfTrimmingSelect: ...
	def Trim1Value(self, num: int) -> StepGeom_TrimmingSelect: ...
	def Trim2(self) -> StepGeom_HArray1OfTrimmingSelect: ...
	def Trim2Value(self, num: int) -> StepGeom_TrimmingSelect: ...

class StepGeom_BSplineCurveWithKnots(StepGeom_BSplineCurve):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aDegree: int, aControlPointsList: StepGeom_HArray1OfCartesianPoint, aCurveForm: StepGeom_BSplineCurveForm, aClosedCurve: StepData_Logical, aSelfIntersect: StepData_Logical, aKnotMultiplicities: TColStd_HArray1OfInteger, aKnots: TColStd_HArray1OfReal, aKnotSpec: StepGeom_KnotType) -> None: ...
	def KnotMultiplicities(self) -> TColStd_HArray1OfInteger: ...
	def KnotMultiplicitiesValue(self, num: int) -> int: ...
	def KnotSpec(self) -> StepGeom_KnotType: ...
	def Knots(self) -> TColStd_HArray1OfReal: ...
	def KnotsValue(self, num: int) -> float: ...
	def NbKnotMultiplicities(self) -> int: ...
	def NbKnots(self) -> int: ...
	def SetKnotMultiplicities(self, aKnotMultiplicities: TColStd_HArray1OfInteger) -> None: ...
	def SetKnotSpec(self, aKnotSpec: StepGeom_KnotType) -> None: ...
	def SetKnots(self, aKnots: TColStd_HArray1OfReal) -> None: ...

class StepGeom_BSplineCurveWithKnotsAndRationalBSplineCurve(StepGeom_BSplineCurve):
	def __init__(self) -> None: ...
	def BSplineCurveWithKnots(self) -> StepGeom_BSplineCurveWithKnots: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aDegree: int, aControlPointsList: StepGeom_HArray1OfCartesianPoint, aCurveForm: StepGeom_BSplineCurveForm, aClosedCurve: StepData_Logical, aSelfIntersect: StepData_Logical, aBSplineCurveWithKnots: StepGeom_BSplineCurveWithKnots, aRationalBSplineCurve: StepGeom_RationalBSplineCurve) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aDegree: int, aControlPointsList: StepGeom_HArray1OfCartesianPoint, aCurveForm: StepGeom_BSplineCurveForm, aClosedCurve: StepData_Logical, aSelfIntersect: StepData_Logical, aKnotMultiplicities: TColStd_HArray1OfInteger, aKnots: TColStd_HArray1OfReal, aKnotSpec: StepGeom_KnotType, aWeightsData: TColStd_HArray1OfReal) -> None: ...
	def KnotMultiplicities(self) -> TColStd_HArray1OfInteger: ...
	def KnotMultiplicitiesValue(self, num: int) -> int: ...
	def KnotSpec(self) -> StepGeom_KnotType: ...
	def Knots(self) -> TColStd_HArray1OfReal: ...
	def KnotsValue(self, num: int) -> float: ...
	def NbKnotMultiplicities(self) -> int: ...
	def NbKnots(self) -> int: ...
	def NbWeightsData(self) -> int: ...
	def RationalBSplineCurve(self) -> StepGeom_RationalBSplineCurve: ...
	def SetBSplineCurveWithKnots(self, aBSplineCurveWithKnots: StepGeom_BSplineCurveWithKnots) -> None: ...
	def SetKnotMultiplicities(self, aKnotMultiplicities: TColStd_HArray1OfInteger) -> None: ...
	def SetKnotSpec(self, aKnotSpec: StepGeom_KnotType) -> None: ...
	def SetKnots(self, aKnots: TColStd_HArray1OfReal) -> None: ...
	def SetRationalBSplineCurve(self, aRationalBSplineCurve: StepGeom_RationalBSplineCurve) -> None: ...
	def SetWeightsData(self, aWeightsData: TColStd_HArray1OfReal) -> None: ...
	def WeightsData(self) -> TColStd_HArray1OfReal: ...
	def WeightsDataValue(self, num: int) -> float: ...

class StepGeom_BSplineSurfaceWithKnots(StepGeom_BSplineSurface):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aUDegree: int, aVDegree: int, aControlPointsList: StepGeom_HArray2OfCartesianPoint, aSurfaceForm: StepGeom_BSplineSurfaceForm, aUClosed: StepData_Logical, aVClosed: StepData_Logical, aSelfIntersect: StepData_Logical, aUMultiplicities: TColStd_HArray1OfInteger, aVMultiplicities: TColStd_HArray1OfInteger, aUKnots: TColStd_HArray1OfReal, aVKnots: TColStd_HArray1OfReal, aKnotSpec: StepGeom_KnotType) -> None: ...
	def KnotSpec(self) -> StepGeom_KnotType: ...
	def NbUKnots(self) -> int: ...
	def NbUMultiplicities(self) -> int: ...
	def NbVKnots(self) -> int: ...
	def NbVMultiplicities(self) -> int: ...
	def SetKnotSpec(self, aKnotSpec: StepGeom_KnotType) -> None: ...
	def SetUKnots(self, aUKnots: TColStd_HArray1OfReal) -> None: ...
	def SetUMultiplicities(self, aUMultiplicities: TColStd_HArray1OfInteger) -> None: ...
	def SetVKnots(self, aVKnots: TColStd_HArray1OfReal) -> None: ...
	def SetVMultiplicities(self, aVMultiplicities: TColStd_HArray1OfInteger) -> None: ...
	def UKnots(self) -> TColStd_HArray1OfReal: ...
	def UKnotsValue(self, num: int) -> float: ...
	def UMultiplicities(self) -> TColStd_HArray1OfInteger: ...
	def UMultiplicitiesValue(self, num: int) -> int: ...
	def VKnots(self) -> TColStd_HArray1OfReal: ...
	def VKnotsValue(self, num: int) -> float: ...
	def VMultiplicities(self) -> TColStd_HArray1OfInteger: ...
	def VMultiplicitiesValue(self, num: int) -> int: ...

class StepGeom_BSplineSurfaceWithKnotsAndRationalBSplineSurface(StepGeom_BSplineSurface):
	def __init__(self) -> None: ...
	def BSplineSurfaceWithKnots(self) -> StepGeom_BSplineSurfaceWithKnots: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aUDegree: int, aVDegree: int, aControlPointsList: StepGeom_HArray2OfCartesianPoint, aSurfaceForm: StepGeom_BSplineSurfaceForm, aUClosed: StepData_Logical, aVClosed: StepData_Logical, aSelfIntersect: StepData_Logical, aBSplineSurfaceWithKnots: StepGeom_BSplineSurfaceWithKnots, aRationalBSplineSurface: StepGeom_RationalBSplineSurface) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aUDegree: int, aVDegree: int, aControlPointsList: StepGeom_HArray2OfCartesianPoint, aSurfaceForm: StepGeom_BSplineSurfaceForm, aUClosed: StepData_Logical, aVClosed: StepData_Logical, aSelfIntersect: StepData_Logical, aUMultiplicities: TColStd_HArray1OfInteger, aVMultiplicities: TColStd_HArray1OfInteger, aUKnots: TColStd_HArray1OfReal, aVKnots: TColStd_HArray1OfReal, aKnotSpec: StepGeom_KnotType, aWeightsData: TColStd_HArray2OfReal) -> None: ...
	def KnotSpec(self) -> StepGeom_KnotType: ...
	def NbUKnots(self) -> int: ...
	def NbUMultiplicities(self) -> int: ...
	def NbVKnots(self) -> int: ...
	def NbVMultiplicities(self) -> int: ...
	def NbWeightsDataI(self) -> int: ...
	def NbWeightsDataJ(self) -> int: ...
	def RationalBSplineSurface(self) -> StepGeom_RationalBSplineSurface: ...
	def SetBSplineSurfaceWithKnots(self, aBSplineSurfaceWithKnots: StepGeom_BSplineSurfaceWithKnots) -> None: ...
	def SetKnotSpec(self, aKnotSpec: StepGeom_KnotType) -> None: ...
	def SetRationalBSplineSurface(self, aRationalBSplineSurface: StepGeom_RationalBSplineSurface) -> None: ...
	def SetUKnots(self, aUKnots: TColStd_HArray1OfReal) -> None: ...
	def SetUMultiplicities(self, aUMultiplicities: TColStd_HArray1OfInteger) -> None: ...
	def SetVKnots(self, aVKnots: TColStd_HArray1OfReal) -> None: ...
	def SetVMultiplicities(self, aVMultiplicities: TColStd_HArray1OfInteger) -> None: ...
	def SetWeightsData(self, aWeightsData: TColStd_HArray2OfReal) -> None: ...
	def UKnots(self) -> TColStd_HArray1OfReal: ...
	def UKnotsValue(self, num: int) -> float: ...
	def UMultiplicities(self) -> TColStd_HArray1OfInteger: ...
	def UMultiplicitiesValue(self, num: int) -> int: ...
	def VKnots(self) -> TColStd_HArray1OfReal: ...
	def VKnotsValue(self, num: int) -> float: ...
	def VMultiplicities(self) -> TColStd_HArray1OfInteger: ...
	def VMultiplicitiesValue(self, num: int) -> int: ...
	def WeightsData(self) -> TColStd_HArray2OfReal: ...
	def WeightsDataValue(self, num1: int, num2: int) -> float: ...

class StepGeom_BezierCurve(StepGeom_BSplineCurve):
	def __init__(self) -> None: ...

class StepGeom_BezierCurveAndRationalBSplineCurve(StepGeom_BSplineCurve):
	def __init__(self) -> None: ...
	def BezierCurve(self) -> StepGeom_BezierCurve: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aDegree: int, aControlPointsList: StepGeom_HArray1OfCartesianPoint, aCurveForm: StepGeom_BSplineCurveForm, aClosedCurve: StepData_Logical, aSelfIntersect: StepData_Logical, aBezierCurve: StepGeom_BezierCurve, aRationalBSplineCurve: StepGeom_RationalBSplineCurve) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aDegree: int, aControlPointsList: StepGeom_HArray1OfCartesianPoint, aCurveForm: StepGeom_BSplineCurveForm, aClosedCurve: StepData_Logical, aSelfIntersect: StepData_Logical, aWeightsData: TColStd_HArray1OfReal) -> None: ...
	def NbWeightsData(self) -> int: ...
	def RationalBSplineCurve(self) -> StepGeom_RationalBSplineCurve: ...
	def SetBezierCurve(self, aBezierCurve: StepGeom_BezierCurve) -> None: ...
	def SetRationalBSplineCurve(self, aRationalBSplineCurve: StepGeom_RationalBSplineCurve) -> None: ...
	def SetWeightsData(self, aWeightsData: TColStd_HArray1OfReal) -> None: ...
	def WeightsData(self) -> TColStd_HArray1OfReal: ...
	def WeightsDataValue(self, num: int) -> float: ...

class StepGeom_BezierSurface(StepGeom_BSplineSurface):
	def __init__(self) -> None: ...

class StepGeom_BezierSurfaceAndRationalBSplineSurface(StepGeom_BSplineSurface):
	def __init__(self) -> None: ...
	def BezierSurface(self) -> StepGeom_BezierSurface: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aUDegree: int, aVDegree: int, aControlPointsList: StepGeom_HArray2OfCartesianPoint, aSurfaceForm: StepGeom_BSplineSurfaceForm, aUClosed: StepData_Logical, aVClosed: StepData_Logical, aSelfIntersect: StepData_Logical, aBezierSurface: StepGeom_BezierSurface, aRationalBSplineSurface: StepGeom_RationalBSplineSurface) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aUDegree: int, aVDegree: int, aControlPointsList: StepGeom_HArray2OfCartesianPoint, aSurfaceForm: StepGeom_BSplineSurfaceForm, aUClosed: StepData_Logical, aVClosed: StepData_Logical, aSelfIntersect: StepData_Logical, aWeightsData: TColStd_HArray2OfReal) -> None: ...
	def NbWeightsDataI(self) -> int: ...
	def NbWeightsDataJ(self) -> int: ...
	def RationalBSplineSurface(self) -> StepGeom_RationalBSplineSurface: ...
	def SetBezierSurface(self, aBezierSurface: StepGeom_BezierSurface) -> None: ...
	def SetRationalBSplineSurface(self, aRationalBSplineSurface: StepGeom_RationalBSplineSurface) -> None: ...
	def SetWeightsData(self, aWeightsData: TColStd_HArray2OfReal) -> None: ...
	def WeightsData(self) -> TColStd_HArray2OfReal: ...
	def WeightsDataValue(self, num1: int, num2: int) -> float: ...

class StepGeom_CompositeCurveOnSurface(StepGeom_CompositeCurve):
	def __init__(self) -> None: ...

class StepGeom_DegenerateToroidalSurface(StepGeom_ToroidalSurface):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aPosition: StepGeom_Axis2Placement3d, aMajorRadius: float, aMinorRadius: float, aSelectOuter: bool) -> None: ...
	def SelectOuter(self) -> bool: ...
	def SetSelectOuter(self, aSelectOuter: bool) -> None: ...

class StepGeom_QuasiUniformCurve(StepGeom_BSplineCurve):
	def __init__(self) -> None: ...

class StepGeom_QuasiUniformCurveAndRationalBSplineCurve(StepGeom_BSplineCurve):
	def __init__(self) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aDegree: int, aControlPointsList: StepGeom_HArray1OfCartesianPoint, aCurveForm: StepGeom_BSplineCurveForm, aClosedCurve: StepData_Logical, aSelfIntersect: StepData_Logical, aQuasiUniformCurve: StepGeom_QuasiUniformCurve, aRationalBSplineCurve: StepGeom_RationalBSplineCurve) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aDegree: int, aControlPointsList: StepGeom_HArray1OfCartesianPoint, aCurveForm: StepGeom_BSplineCurveForm, aClosedCurve: StepData_Logical, aSelfIntersect: StepData_Logical, aWeightsData: TColStd_HArray1OfReal) -> None: ...
	def NbWeightsData(self) -> int: ...
	def QuasiUniformCurve(self) -> StepGeom_QuasiUniformCurve: ...
	def RationalBSplineCurve(self) -> StepGeom_RationalBSplineCurve: ...
	def SetQuasiUniformCurve(self, aQuasiUniformCurve: StepGeom_QuasiUniformCurve) -> None: ...
	def SetRationalBSplineCurve(self, aRationalBSplineCurve: StepGeom_RationalBSplineCurve) -> None: ...
	def SetWeightsData(self, aWeightsData: TColStd_HArray1OfReal) -> None: ...
	def WeightsData(self) -> TColStd_HArray1OfReal: ...
	def WeightsDataValue(self, num: int) -> float: ...

class StepGeom_QuasiUniformSurface(StepGeom_BSplineSurface):
	def __init__(self) -> None: ...

class StepGeom_QuasiUniformSurfaceAndRationalBSplineSurface(StepGeom_BSplineSurface):
	def __init__(self) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aUDegree: int, aVDegree: int, aControlPointsList: StepGeom_HArray2OfCartesianPoint, aSurfaceForm: StepGeom_BSplineSurfaceForm, aUClosed: StepData_Logical, aVClosed: StepData_Logical, aSelfIntersect: StepData_Logical, aQuasiUniformSurface: StepGeom_QuasiUniformSurface, aRationalBSplineSurface: StepGeom_RationalBSplineSurface) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aUDegree: int, aVDegree: int, aControlPointsList: StepGeom_HArray2OfCartesianPoint, aSurfaceForm: StepGeom_BSplineSurfaceForm, aUClosed: StepData_Logical, aVClosed: StepData_Logical, aSelfIntersect: StepData_Logical, aWeightsData: TColStd_HArray2OfReal) -> None: ...
	def NbWeightsDataI(self) -> int: ...
	def NbWeightsDataJ(self) -> int: ...
	def QuasiUniformSurface(self) -> StepGeom_QuasiUniformSurface: ...
	def RationalBSplineSurface(self) -> StepGeom_RationalBSplineSurface: ...
	def SetQuasiUniformSurface(self, aQuasiUniformSurface: StepGeom_QuasiUniformSurface) -> None: ...
	def SetRationalBSplineSurface(self, aRationalBSplineSurface: StepGeom_RationalBSplineSurface) -> None: ...
	def SetWeightsData(self, aWeightsData: TColStd_HArray2OfReal) -> None: ...
	def WeightsData(self) -> TColStd_HArray2OfReal: ...
	def WeightsDataValue(self, num1: int, num2: int) -> float: ...

class StepGeom_RationalBSplineCurve(StepGeom_BSplineCurve):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aDegree: int, aControlPointsList: StepGeom_HArray1OfCartesianPoint, aCurveForm: StepGeom_BSplineCurveForm, aClosedCurve: StepData_Logical, aSelfIntersect: StepData_Logical, aWeightsData: TColStd_HArray1OfReal) -> None: ...
	def NbWeightsData(self) -> int: ...
	def SetWeightsData(self, aWeightsData: TColStd_HArray1OfReal) -> None: ...
	def WeightsData(self) -> TColStd_HArray1OfReal: ...
	def WeightsDataValue(self, num: int) -> float: ...

class StepGeom_RationalBSplineSurface(StepGeom_BSplineSurface):
	def __init__(self) -> None: ...
	def Init(self, aName: TCollection_HAsciiString, aUDegree: int, aVDegree: int, aControlPointsList: StepGeom_HArray2OfCartesianPoint, aSurfaceForm: StepGeom_BSplineSurfaceForm, aUClosed: StepData_Logical, aVClosed: StepData_Logical, aSelfIntersect: StepData_Logical, aWeightsData: TColStd_HArray2OfReal) -> None: ...
	def NbWeightsDataI(self) -> int: ...
	def NbWeightsDataJ(self) -> int: ...
	def SetWeightsData(self, aWeightsData: TColStd_HArray2OfReal) -> None: ...
	def WeightsData(self) -> TColStd_HArray2OfReal: ...
	def WeightsDataValue(self, num1: int, num2: int) -> float: ...

class StepGeom_UniformCurve(StepGeom_BSplineCurve):
	def __init__(self) -> None: ...

class StepGeom_UniformCurveAndRationalBSplineCurve(StepGeom_BSplineCurve):
	def __init__(self) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aDegree: int, aControlPointsList: StepGeom_HArray1OfCartesianPoint, aCurveForm: StepGeom_BSplineCurveForm, aClosedCurve: StepData_Logical, aSelfIntersect: StepData_Logical, aUniformCurve: StepGeom_UniformCurve, aRationalBSplineCurve: StepGeom_RationalBSplineCurve) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aDegree: int, aControlPointsList: StepGeom_HArray1OfCartesianPoint, aCurveForm: StepGeom_BSplineCurveForm, aClosedCurve: StepData_Logical, aSelfIntersect: StepData_Logical, aWeightsData: TColStd_HArray1OfReal) -> None: ...
	def NbWeightsData(self) -> int: ...
	def RationalBSplineCurve(self) -> StepGeom_RationalBSplineCurve: ...
	def SetRationalBSplineCurve(self, aRationalBSplineCurve: StepGeom_RationalBSplineCurve) -> None: ...
	def SetUniformCurve(self, aUniformCurve: StepGeom_UniformCurve) -> None: ...
	def SetWeightsData(self, aWeightsData: TColStd_HArray1OfReal) -> None: ...
	def UniformCurve(self) -> StepGeom_UniformCurve: ...
	def WeightsData(self) -> TColStd_HArray1OfReal: ...
	def WeightsDataValue(self, num: int) -> float: ...

class StepGeom_UniformSurface(StepGeom_BSplineSurface):
	def __init__(self) -> None: ...

class StepGeom_UniformSurfaceAndRationalBSplineSurface(StepGeom_BSplineSurface):
	def __init__(self) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aUDegree: int, aVDegree: int, aControlPointsList: StepGeom_HArray2OfCartesianPoint, aSurfaceForm: StepGeom_BSplineSurfaceForm, aUClosed: StepData_Logical, aVClosed: StepData_Logical, aSelfIntersect: StepData_Logical, aUniformSurface: StepGeom_UniformSurface, aRationalBSplineSurface: StepGeom_RationalBSplineSurface) -> None: ...
	@overload
	def Init(self, aName: TCollection_HAsciiString, aUDegree: int, aVDegree: int, aControlPointsList: StepGeom_HArray2OfCartesianPoint, aSurfaceForm: StepGeom_BSplineSurfaceForm, aUClosed: StepData_Logical, aVClosed: StepData_Logical, aSelfIntersect: StepData_Logical, aWeightsData: TColStd_HArray2OfReal) -> None: ...
	def NbWeightsDataI(self) -> int: ...
	def NbWeightsDataJ(self) -> int: ...
	def RationalBSplineSurface(self) -> StepGeom_RationalBSplineSurface: ...
	def SetRationalBSplineSurface(self, aRationalBSplineSurface: StepGeom_RationalBSplineSurface) -> None: ...
	def SetUniformSurface(self, aUniformSurface: StepGeom_UniformSurface) -> None: ...
	def SetWeightsData(self, aWeightsData: TColStd_HArray2OfReal) -> None: ...
	def UniformSurface(self) -> StepGeom_UniformSurface: ...
	def WeightsData(self) -> TColStd_HArray2OfReal: ...
	def WeightsDataValue(self, num1: int, num2: int) -> float: ...

class StepGeom_BoundaryCurve(StepGeom_CompositeCurveOnSurface):
	def __init__(self) -> None: ...

class StepGeom_OuterBoundaryCurve(StepGeom_BoundaryCurve):
	def __init__(self) -> None: ...

# harray1 classes

class StepGeom_HArray1OfCartesianPoint(StepGeom_Array1OfCartesianPoint, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepGeom_Array1OfCartesianPoint: ...


class StepGeom_HArray1OfPcurveOrSurface(StepGeom_Array1OfPcurveOrSurface, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepGeom_Array1OfPcurveOrSurface: ...


class StepGeom_HArray1OfSurfaceBoundary(StepGeom_Array1OfSurfaceBoundary, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepGeom_Array1OfSurfaceBoundary: ...


class StepGeom_HArray1OfBoundaryCurve(StepGeom_Array1OfBoundaryCurve, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepGeom_Array1OfBoundaryCurve: ...


class StepGeom_HArray1OfCompositeCurveSegment(StepGeom_Array1OfCompositeCurveSegment, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepGeom_Array1OfCompositeCurveSegment: ...


class StepGeom_HArray1OfCurve(StepGeom_Array1OfCurve, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepGeom_Array1OfCurve: ...


class StepGeom_HArray1OfTrimmingSelect(StepGeom_Array1OfTrimmingSelect, Standard_Transient):
    def __init__(self, theLower: int, theUpper: int) -> None: ...
    def Array1(self) -> StepGeom_Array1OfTrimmingSelect: ...

# harray2 classes

class StepGeom_HArray2OfSurfacePatch(StepGeom_Array2OfSurfacePatch, Standard_Transient):
    @overload
    def __init__(self, theRowLow: int, theRowUpp: int, theColLow: int, theColUpp: int) -> None: ...
    @overload
    def __init__(self, theOther: StepGeom_Array2OfSurfacePatch) -> None: ...
    def Array2(self) -> StepGeom_Array2OfSurfacePatch: ...


class StepGeom_HArray2OfCartesianPoint(StepGeom_Array2OfCartesianPoint, Standard_Transient):
    @overload
    def __init__(self, theRowLow: int, theRowUpp: int, theColLow: int, theColUpp: int) -> None: ...
    @overload
    def __init__(self, theOther: StepGeom_Array2OfCartesianPoint) -> None: ...
    def Array2(self) -> StepGeom_Array2OfCartesianPoint: ...

# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Geom import *
from OCC.Core.GeomAbs import *
from OCC.Core.gp import *


class geomlprop:
	@overload
	@staticmethod
	def Continuity(C1: Geom_Curve, C2: Geom_Curve, u1: float, u2: float, r1: bool, r2: bool, tl: float, ta: float) -> GeomAbs_Shape: ...
	@overload
	@staticmethod
	def Continuity(C1: Geom_Curve, C2: Geom_Curve, u1: float, u2: float, r1: bool, r2: bool) -> GeomAbs_Shape: ...

class GeomLProp_CLProps:
	@overload
	def __init__(self, C: Geom_Curve, N: int, Resolution: float) -> None: ...
	@overload
	def __init__(self, C: Geom_Curve, U: float, N: int, Resolution: float) -> None: ...
	@overload
	def __init__(self, N: int, Resolution: float) -> None: ...
	def CentreOfCurvature(self, P: gp_Pnt) -> None: ...
	def Curvature(self) -> float: ...
	def D1(self) -> gp_Vec: ...
	def D2(self) -> gp_Vec: ...
	def D3(self) -> gp_Vec: ...
	def IsTangentDefined(self) -> bool: ...
	def Normal(self, N: gp_Dir) -> None: ...
	def SetCurve(self, C: Geom_Curve) -> None: ...
	def SetParameter(self, U: float) -> None: ...
	def Tangent(self, D: gp_Dir) -> None: ...
	def Value(self) -> gp_Pnt: ...

class GeomLProp_CurveTool:
	@staticmethod
	def Continuity(C: Geom_Curve) -> int: ...
	@staticmethod
	def D1(C: Geom_Curve, U: float, P: gp_Pnt, V1: gp_Vec) -> None: ...
	@staticmethod
	def D2(C: Geom_Curve, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec) -> None: ...
	@staticmethod
	def D3(C: Geom_Curve, U: float, P: gp_Pnt, V1: gp_Vec, V2: gp_Vec, V3: gp_Vec) -> None: ...
	@staticmethod
	def FirstParameter(C: Geom_Curve) -> float: ...
	@staticmethod
	def LastParameter(C: Geom_Curve) -> float: ...
	@staticmethod
	def Value(C: Geom_Curve, U: float, P: gp_Pnt) -> None: ...

class GeomLProp_SLProps:
	@overload
	def __init__(self, S: Geom_Surface, U: float, V: float, N: int, Resolution: float) -> None: ...
	@overload
	def __init__(self, S: Geom_Surface, N: int, Resolution: float) -> None: ...
	@overload
	def __init__(self, N: int, Resolution: float) -> None: ...
	def CurvatureDirections(self, MaxD: gp_Dir, MinD: gp_Dir) -> None: ...
	def D1U(self) -> gp_Vec: ...
	def D1V(self) -> gp_Vec: ...
	def D2U(self) -> gp_Vec: ...
	def D2V(self) -> gp_Vec: ...
	def DUV(self) -> gp_Vec: ...
	def GaussianCurvature(self) -> float: ...
	def IsCurvatureDefined(self) -> bool: ...
	def IsNormalDefined(self) -> bool: ...
	def IsTangentUDefined(self) -> bool: ...
	def IsTangentVDefined(self) -> bool: ...
	def IsUmbilic(self) -> bool: ...
	def MaxCurvature(self) -> float: ...
	def MeanCurvature(self) -> float: ...
	def MinCurvature(self) -> float: ...
	def Normal(self) -> gp_Dir: ...
	def SetParameters(self, U: float, V: float) -> None: ...
	def SetSurface(self, S: Geom_Surface) -> None: ...
	def TangentU(self, D: gp_Dir) -> None: ...
	def TangentV(self, D: gp_Dir) -> None: ...
	def Value(self) -> gp_Pnt: ...

class GeomLProp_SurfaceTool:
	@staticmethod
	def Bounds(S: Geom_Surface) -> Tuple[float, float, float, float]: ...
	@staticmethod
	def Continuity(S: Geom_Surface) -> int: ...
	@staticmethod
	def D1(S: Geom_Surface, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec) -> None: ...
	@staticmethod
	def D2(S: Geom_Surface, U: float, V: float, P: gp_Pnt, D1U: gp_Vec, D1V: gp_Vec, D2U: gp_Vec, D2V: gp_Vec, DUV: gp_Vec) -> None: ...
	@staticmethod
	def DN(S: Geom_Surface, U: float, V: float, IU: int, IV: int) -> gp_Vec: ...
	@staticmethod
	def Value(S: Geom_Surface, U: float, V: float, P: gp_Pnt) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

geomlprop_Continuity = geomlprop.Continuity
geomlprop_Continuity = geomlprop.Continuity
GeomLProp_CurveTool_Continuity = GeomLProp_CurveTool.Continuity
GeomLProp_CurveTool_D1 = GeomLProp_CurveTool.D1
GeomLProp_CurveTool_D2 = GeomLProp_CurveTool.D2
GeomLProp_CurveTool_D3 = GeomLProp_CurveTool.D3
GeomLProp_CurveTool_FirstParameter = GeomLProp_CurveTool.FirstParameter
GeomLProp_CurveTool_LastParameter = GeomLProp_CurveTool.LastParameter
GeomLProp_CurveTool_Value = GeomLProp_CurveTool.Value
GeomLProp_SurfaceTool_Bounds = GeomLProp_SurfaceTool.Bounds
GeomLProp_SurfaceTool_Continuity = GeomLProp_SurfaceTool.Continuity
GeomLProp_SurfaceTool_D1 = GeomLProp_SurfaceTool.D1
GeomLProp_SurfaceTool_D2 = GeomLProp_SurfaceTool.D2
GeomLProp_SurfaceTool_DN = GeomLProp_SurfaceTool.DN
GeomLProp_SurfaceTool_Value = GeomLProp_SurfaceTool.Value



from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.LDOM import *
from OCC.Core.TCollection import *
from OCC.Core.gp import *
from OCC.Core.TColStd import *
from OCC.Core.Storage import *

XmlObjMgt_DOMString = NewType('XmlObjMgt_DOMString', LDOMString)
XmlObjMgt_Document = NewType('XmlObjMgt_Document', LDOM_Document)
XmlObjMgt_Element = NewType('XmlObjMgt_Element', LDOM_Element)

class xmlobjmgt:
	@staticmethod
	def FindChildByName(theSource: XmlObjMgt_Element, theName: XmlObjMgt_DOMString) -> XmlObjMgt_Element: ...
	@staticmethod
	def FindChildByRef(theSource: XmlObjMgt_Element, theRefName: XmlObjMgt_DOMString) -> XmlObjMgt_Element: ...
	@staticmethod
	def FindChildElement(theSource: XmlObjMgt_Element, theObjId: int) -> XmlObjMgt_Element: ...
	@staticmethod
	def GetExtendedString(theElement: XmlObjMgt_Element, theString: TCollection_ExtendedString) -> bool: ...
	@staticmethod
	def GetInteger(theString: str) -> Tuple[bool, int]: ...
	@overload
	@staticmethod
	def GetReal(theString: str) -> Tuple[bool, float]: ...
	@overload
	@staticmethod
	def GetReal(theString: XmlObjMgt_DOMString) -> Tuple[bool, float]: ...
	@staticmethod
	def GetStringValue(theElement: XmlObjMgt_Element) -> XmlObjMgt_DOMString: ...
	@staticmethod
	def GetTagEntryString(theTarget: XmlObjMgt_DOMString, theTagEntry: TCollection_AsciiString) -> bool: ...
	@staticmethod
	def IdString() -> XmlObjMgt_DOMString: ...
	@staticmethod
	def SetExtendedString(theElement: XmlObjMgt_Element, theString: TCollection_ExtendedString) -> bool: ...
	@staticmethod
	def SetStringValue(theElement: XmlObjMgt_Element, theData: XmlObjMgt_DOMString, isClearText: Optional[bool] = False) -> None: ...
	@staticmethod
	def SetTagEntryString(theSource: XmlObjMgt_DOMString, theTagEntry: TCollection_AsciiString) -> None: ...

class XmlObjMgt_Array1:
	@overload
	def __init__(self, Low: int, Up: int) -> None: ...
	@overload
	def __init__(self, theParent: XmlObjMgt_Element, theName: XmlObjMgt_DOMString) -> None: ...
	def CreateArrayElement(self, theParent: XmlObjMgt_Element, theName: XmlObjMgt_DOMString) -> None: ...
	def Element(self) -> XmlObjMgt_Element: ...
	def Length(self) -> int: ...
	def Lower(self) -> int: ...
	def SetValue(self, Index: int, Value: XmlObjMgt_Element) -> None: ...
	def Upper(self) -> int: ...
	def Value(self, Index: int) -> XmlObjMgt_Element: ...

class XmlObjMgt_GP:
	@overload
	@staticmethod
	def Translate(aTrsf: gp_Trsf) -> XmlObjMgt_DOMString: ...
	@overload
	@staticmethod
	def Translate(aMat: gp_Mat) -> XmlObjMgt_DOMString: ...
	@overload
	@staticmethod
	def Translate(anXYZ: gp_XYZ) -> XmlObjMgt_DOMString: ...
	@overload
	@staticmethod
	def Translate(aStr: XmlObjMgt_DOMString, T: gp_Trsf) -> bool: ...
	@overload
	@staticmethod
	def Translate(aStr: XmlObjMgt_DOMString, T: gp_Mat) -> bool: ...
	@overload
	@staticmethod
	def Translate(aStr: XmlObjMgt_DOMString, T: gp_XYZ) -> bool: ...

class XmlObjMgt_Persistent:
	@overload
	def __init__(self) -> None: ...
	@overload
	def __init__(self, theElement: XmlObjMgt_Element) -> None: ...
	@overload
	def __init__(self, theElement: XmlObjMgt_Element, theRef: XmlObjMgt_DOMString) -> None: ...
	def CreateElement(self, theParent: XmlObjMgt_Element, theType: XmlObjMgt_DOMString, theID: int) -> None: ...
	@overload
	def Element(self) -> XmlObjMgt_Element: ...
	@overload
	def Element(self) -> XmlObjMgt_Element: ...
	def Id(self) -> int: ...
	def SetId(self, theId: int) -> None: ...

class XmlObjMgt_RRelocationTable(TColStd_DataMapOfIntegerTransient):
	def Clear(self, doReleaseMemory: Optional[bool] = True) -> None: ...
	def GetHeaderData(self) -> Storage_HeaderData: ...
	def SetHeaderData(self, theHeaderData: Storage_HeaderData) -> None: ...

class XmlObjMgt_SRelocationTable(TColStd_IndexedMapOfTransient):
	def Clear(self, doReleaseMemory: Optional[bool] = True) -> None: ...
	def GetHeaderData(self) -> Storage_HeaderData: ...
	def SetHeaderData(self, theHeaderData: Storage_HeaderData) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

xmlobjmgt_FindChildByName = xmlobjmgt.FindChildByName
xmlobjmgt_FindChildByRef = xmlobjmgt.FindChildByRef
xmlobjmgt_FindChildElement = xmlobjmgt.FindChildElement
xmlobjmgt_GetExtendedString = xmlobjmgt.GetExtendedString
xmlobjmgt_GetInteger = xmlobjmgt.GetInteger
xmlobjmgt_GetReal = xmlobjmgt.GetReal
xmlobjmgt_GetReal = xmlobjmgt.GetReal
xmlobjmgt_GetStringValue = xmlobjmgt.GetStringValue
xmlobjmgt_GetTagEntryString = xmlobjmgt.GetTagEntryString
xmlobjmgt_IdString = xmlobjmgt.IdString
xmlobjmgt_SetExtendedString = xmlobjmgt.SetExtendedString
xmlobjmgt_SetStringValue = xmlobjmgt.SetStringValue
xmlobjmgt_SetTagEntryString = xmlobjmgt.SetTagEntryString
XmlObjMgt_GP_Translate = XmlObjMgt_GP.Translate
XmlObjMgt_GP_Translate = XmlObjMgt_GP.Translate
XmlObjMgt_GP_Translate = XmlObjMgt_GP.Translate
XmlObjMgt_GP_Translate = XmlObjMgt_GP.Translate
XmlObjMgt_GP_Translate = XmlObjMgt_GP.Translate
XmlObjMgt_GP_Translate = XmlObjMgt_GP.Translate



# This file was automatically generated by SWIG (http://www.swig.org).
# Version 4.0.2
#
# Do not make changes to this file unless you know what you are doing--modify
# the SWIG interface file instead.

"""
AppStdL module, see official documentation at
https://www.opencascade.com/doc/occt-7.4.0/refman/html/package_appstdl.html
"""

from sys import version_info as _swig_python_version_info
if _swig_python_version_info < (2, 7, 0):
    raise RuntimeError("Python 2.7 or later required")

# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _AppStdL
else:
    import _AppStdL

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "thisown":
            self.this.own(value)
        elif name == "this":
            set(self, name, value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


class SwigPyIterator(object):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr
    __swig_destroy__ = _AppStdL.delete_SwigPyIterator

    def value(self) -> "PyObject *":
        return _AppStdL.SwigPyIterator_value(self)

    def incr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _AppStdL.SwigPyIterator_incr(self, n)

    def decr(self, n: "size_t"=1) -> "swig::SwigPyIterator *":
        return _AppStdL.SwigPyIterator_decr(self, n)

    def distance(self, x: "SwigPyIterator") -> "ptrdiff_t":
        return _AppStdL.SwigPyIterator_distance(self, x)

    def equal(self, x: "SwigPyIterator") -> "bool":
        return _AppStdL.SwigPyIterator_equal(self, x)

    def copy(self) -> "swig::SwigPyIterator *":
        return _AppStdL.SwigPyIterator_copy(self)

    def next(self) -> "PyObject *":
        return _AppStdL.SwigPyIterator_next(self)

    def __next__(self) -> "PyObject *":
        return _AppStdL.SwigPyIterator___next__(self)

    def previous(self) -> "PyObject *":
        return _AppStdL.SwigPyIterator_previous(self)

    def advance(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _AppStdL.SwigPyIterator_advance(self, n)

    def __eq__(self, x: "SwigPyIterator") -> "bool":
        return _AppStdL.SwigPyIterator___eq__(self, x)

    def __ne__(self, x: "SwigPyIterator") -> "bool":
        return _AppStdL.SwigPyIterator___ne__(self, x)

    def __iadd__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _AppStdL.SwigPyIterator___iadd__(self, n)

    def __isub__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator &":
        return _AppStdL.SwigPyIterator___isub__(self, n)

    def __add__(self, n: "ptrdiff_t") -> "swig::SwigPyIterator *":
        return _AppStdL.SwigPyIterator___add__(self, n)

    def __sub__(self, *args) -> "ptrdiff_t":
        return _AppStdL.SwigPyIterator___sub__(self, *args)
    def __iter__(self):
        return self

# Register SwigPyIterator in _AppStdL:
_AppStdL.SwigPyIterator_swigregister(SwigPyIterator)


def _dumps_object(klass):
    """ Overwrite default string output for any wrapped object.
    By default, __repr__ method returns something like:
    <OCC.Core.TopoDS.TopoDS_Shape; proxy of <Swig Object of type 'TopoDS_Shape *' at 0x02BB0758> >
    This is too much verbose.
    We prefer :
    <class 'gp_Pnt'>
    or
    <class 'TopoDS_Shape'>
    """
    klass_name = str(klass.__class__).split(".")[3].split("'")[0]
    repr_string = "<class '" + klass_name + "'"
# for TopoDS_Shape, we also look for the base type
    if klass_name == "TopoDS_Shape":
        if klass.IsNull():
            repr_string += ": Null>"
            return repr_string
        st = klass.ShapeType()
        types = {OCC.Core.TopAbs.TopAbs_VERTEX: "Vertex",
                 OCC.Core.TopAbs.TopAbs_SOLID: "Solid",
                 OCC.Core.TopAbs.TopAbs_EDGE: "Edge",
                 OCC.Core.TopAbs.TopAbs_FACE: "Face",
                 OCC.Core.TopAbs.TopAbs_SHELL: "Shell",
                 OCC.Core.TopAbs.TopAbs_WIRE: "Wire",
                 OCC.Core.TopAbs.TopAbs_COMPOUND: "Compound",
                 OCC.Core.TopAbs.TopAbs_COMPSOLID: "Compsolid"}
        repr_string += "; Type:%s" % types[st]        
    elif hasattr(klass, "IsNull"):
        if klass.IsNull():
            repr_string += "; Null"
    repr_string += ">"
    return repr_string


def process_exception(error: "Standard_Failure", method_name: "std::string", class_name: "std::string") -> "void":
    return _AppStdL.process_exception(error, method_name, class_name)

from six import with_metaclass
import warnings
from OCC.Wrapper.wrapper_utils import Proxy, deprecated

import OCC.Core.Standard
import OCC.Core.NCollection
import OCC.Core.TDocStd
import OCC.Core.TDF
import OCC.Core.TCollection
import OCC.Core.TColStd
import OCC.Core.CDF
import OCC.Core.CDM
import OCC.Core.Message
import OCC.Core.OSD
import OCC.Core.Resource
import OCC.Core.PCDM
import OCC.Core.Storage

from enum import IntEnum
from OCC.Core.Exception import *




def Handle_AppStdL_Application_Create() -> "opencascade::handle< AppStdL_Application >":
    return _AppStdL.Handle_AppStdL_Application_Create()

def Handle_AppStdL_Application_DownCast(t: "opencascade::handle< Standard_Transient > const &") -> "opencascade::handle< AppStdL_Application >":
    return _AppStdL.Handle_AppStdL_Application_DownCast(t)

def Handle_AppStdL_Application_IsNull(t: "opencascade::handle< AppStdL_Application > const &") -> "bool":
    return _AppStdL.Handle_AppStdL_Application_IsNull(t)
class AppStdL_Application(OCC.Core.TDocStd.TDocStd_Application):
    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")
    __repr__ = _swig_repr

    def DumpJsonToString(self, depth: "int"=-1) -> "std::string":
        r"""DumpJsonToString(AppStdL_Application self, int depth=-1) -> std::string"""
        return _AppStdL.AppStdL_Application_DumpJsonToString(self, depth)


    @staticmethod
    def DownCast(t):
      return Handle_AppStdL_Application_DownCast(t)


    __repr__ = _dumps_object


    def __init__(self):
        r"""__init__(AppStdL_Application self) -> AppStdL_Application"""
        _AppStdL.AppStdL_Application_swiginit(self, _AppStdL.new_AppStdL_Application())
    __swig_destroy__ = _AppStdL.delete_AppStdL_Application

# Register AppStdL_Application in _AppStdL:
_AppStdL.AppStdL_Application_swigregister(AppStdL_Application)








from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.gp import *
from OCC.Core.TopAbs import *


class IntStart_SITopolTool(Standard_Transient):
	def Classify(self, P: gp_Pnt2d, Tol: float) -> TopAbs_State: ...

# harray1 classes
# harray2 classes
# hsequence classes




from enum import IntEnum
from typing import overload, NewType, Optional, Tuple

from OCC.Core.Standard import *
from OCC.Core.NCollection import *
from OCC.Core.Geom import *
from OCC.Core.Geom2d import *


class geomtools:
	@staticmethod
	def GetUndefinedTypeHandler() -> GeomTools_UndefinedTypeHandler: ...
	@staticmethod
	def SetUndefinedTypeHandler(aHandler: GeomTools_UndefinedTypeHandler) -> None: ...

class GeomTools_Curve2dSet:
	def __init__(self) -> None: ...
	def Add(self, C: Geom2d_Curve) -> int: ...
	def Clear(self) -> None: ...
	def Curve2d(self, I: int) -> Geom2d_Curve: ...
	def Index(self, C: Geom2d_Curve) -> int: ...

class GeomTools_CurveSet:
	def __init__(self) -> None: ...
	def Add(self, C: Geom_Curve) -> int: ...
	def Clear(self) -> None: ...
	def Curve(self, I: int) -> Geom_Curve: ...
	def Index(self, C: Geom_Curve) -> int: ...

class GeomTools_SurfaceSet:
	def __init__(self) -> None: ...
	def Add(self, S: Geom_Surface) -> int: ...
	def Clear(self) -> None: ...
	def Index(self, S: Geom_Surface) -> int: ...
	def Surface(self, I: int) -> Geom_Surface: ...

class GeomTools_UndefinedTypeHandler(Standard_Transient):
	def __init__(self) -> None: ...

# harray1 classes
# harray2 classes
# hsequence classes

geomtools_Dump = geomtools.Dump
geomtools_Dump = geomtools.Dump
geomtools_Dump = geomtools.Dump
geomtools_GetReal = geomtools.GetReal
geomtools_GetUndefinedTypeHandler = geomtools.GetUndefinedTypeHandler
geomtools_Read = geomtools.Read
geomtools_Read = geomtools.Read
geomtools_Read = geomtools.Read
geomtools_SetUndefinedTypeHandler = geomtools.SetUndefinedTypeHandler
geomtools_Write = geomtools.Write
geomtools_Write = geomtools.Write
geomtools_Write = geomtools.Write
GeomTools_Curve2dSet_PrintCurve2d = GeomTools_Curve2dSet.PrintCurve2d
GeomTools_CurveSet_PrintCurve = GeomTools_CurveSet.PrintCurve
GeomTools_SurfaceSet_PrintSurface = GeomTools_SurfaceSet.PrintSurface
